@@ -43,7 +43,10 @@ async def get_version():
   async def __call__(name, config):
 
     if isinstance(config, dict):
-      _config = configparser.ConfigParser(dict_type=dict, allow_no_value=True)
+      _config = configparser.ConfigParser(
+        dict_type=dict, allow_no_value=True,
+        interpolation=None,
+      )
       _config.read_dict({name: config})
       config = _config[name]
 
@@ -70,3 +73,9 @@ def raise_on_logger_msg():
     return event_dict['event']
 
   structlog.configure([proc])
+
+def pytest_configure(config):
+  # register an additional marker
+  config.addinivalue_line(
+    'markers', 'needs_net: mark test to require Internet access',
+  )
